@@ -1,3 +1,4 @@
+import subprocess
 import sys
 
 from .display import Display
@@ -10,9 +11,16 @@ __all__ = ['sm', 'keys']
 keys = Keys()
 
 
-class Simulant(Keyboard, Mouse, Display):
+class Simulant:
     def __init__(self):
         self.os = sys.platform
+        self.keyboard = Keyboard()
+        self.display = Display()
+        self.mouse = Mouse()
+
+    @staticmethod
+    def get_clipboard():
+        return subprocess.check_output(["xclip", "-o"]).decode('utf-8')
 
     def __str__(self):
         return self.__repr__()
