@@ -2,7 +2,8 @@ from Xlib import display as disp
 from Xlib import X
 from PIL import Image
 
-from simulant.display.window import Window
+from simulant.display.panel import Panel
+from simulant.display.screen import Screen
 
 
 def display_handler(f):
@@ -16,9 +17,15 @@ def display_handler(f):
 
 
 class Display:
-    @staticmethod
-    def get_window(class_name):
-        return Window(class_name=class_name)
+    screens = []
+
+    def __init__(self):
+        self.panel = Panel()
+        self.screens.append(Screen(0))  # todo: xdotool get all screens
+        self.current_screen = self.screens[0]
+
+    def screen(self, number):
+        return [i for i in self.screens if i.screen.number == number]
 
     @property
     def dsp(self):
